@@ -4,7 +4,7 @@ use utf8; # encoding="utf-8"
 use warnings;
 use strict;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Acme::CPANAuthors::Register (
 	ABALAMA   => 'Lepenkov Sergey',
@@ -17,21 +17,28 @@ use Acme::CPANAuthors::Register (
 	AMALTSEV  => 'Andrew Maltsev',
 	AML       => 'Alexander Lourier',
 	ANDY      => 'Andrew Shitov',
+	APLA      => 'Иван Бахчеев',
 	ARTO      => 'Artur Penttinen',
 	ASVBR     => 'Alexey Sharafutdinov',
 	ATOURBIN  => 'Alexey Tourbin',
 	AVP       => 'Alexey V. Presnyakov',
+	AZJADFTRE => 'Павел Купцов',
 	BASHLOV   => 'Dmitry Bashlov',
+	BITTER    => 'Konstantin Vlasov',
 	BOSU      => 'Boris Sukholitko',
 	BUTILW    => 'Ilya Butakov',
 	BWIZARD   => 'Arapov Denis',
 	CATONE    => 'Denis Pokataev',
+	CCCP      => 'Sivirinov Ivan',
+	CLEONTY   => 'Леонтий Чудинов',
+	DAM       => 'Дамян Иванов',
 	DARKNOS   => 'Sergey Nosenko',
 	DAVINCHI  => 'Pavel Boldin',
 	DEEMON    => 'Dmitry Dorofeev',
 	DESPAIR   => 'Walery Studennikov',
 	DMITRI    => 'Dmitri Tikhonov',
 	DMITRY    => 'Dmitry Nikolayev',
+	DMITRYNOD => 'Дмитрий Константинов',
 	DMITRYSOL => 'Dmitri Sologoubenko',
 	DMOW      => 'Dmitry Ovsyanko',
 	DPETROV   => 'Denis Petrov',
@@ -40,26 +47,37 @@ use Acme::CPANAuthors::Register (
 	FEDOROV   => 'Dmitry Fedorov',
 	FILIN     => 'Andrey  Chergik',
 	FLAMEY    => 'Irakliy Sunguryan',
+	FROLLER   => 'Александр Фролов',
 	GARIEV    => 'Igor Gariev',
 	GDSL      => 'Sergey Skvortsov',
 	GLORYBOX  => 'Sergey Sinkovskiy',
 	GOSHA     => 'Okunev Igor',
 	GRAYKOT   => 'Sergey Kotenko',
+	GRIAN     => 'Анатолий Гришаев',
 	GRISHACE  => 'Gregory Belenky',
 	ICHE      => 'Ilya Chelpanov',
 	ICHUDOV   => 'Igor Chudov',
+	IFROL     => 'Иван Фролков',
 	IGORM     => 'Igor Myroshnichenko',
 	INEULANDE => 'Ivan Neulander',
+	ISAGE     => 'Епифанов Иван',
 	ISTERIN   => 'Ilya Sterin',
+	ITRUNAEV  => 'Ivan Trunaev',
 	IVSOKOLOV => 'Ivan Sokolov',
 	KAKADU    => 'Konstantin Kapitanov',
+	KAPPA     => 'Алексей Капранов',
 	KARASIK   => 'Dmitry Karasik',
 	KDOULEPOV => 'Konstantin Doulepov',
 	KES       => 'Eugen Konkov',
 	KEU       => 'Dmitry V. Kolvakh',
+	KIRILLM   => 'Кирилл Мязин',
 	KLIMKIN   => 'Alexey Klimkin',
 	KOTEROV   => 'Dmitry Koterov',
 	KPV       => 'Pavel V. Kaygorodov',
+	KSTEPME   => 'Konstantin Stepanov',
+	KSURI     => 'Алексей Суриков',
+	KVENTIN   => 'Константин Матюхин',
+	LEO       => 'Черепанов Леонид',
 	LESV      => 'Suhanov Vadim',
 	LEXUS     => 'Usanov Alexey',
 	LIOL      => 'Lobanov Igor',
@@ -68,13 +86,16 @@ use Acme::CPANAuthors::Register (
 	LONERR    => 'Oleg A. Mamontov',
 	MAKAROW   => 'Andrew V. Makarow',
 	MAXICO    => 'Maxim Kashliak',
+	MBASOV    => 'Михаил В. Басов',
 	MIT       => 'Dmitriy Dontsov',
 	MONS      => 'Mons Anderson',
 	MPG       => 'Maxim  Grigoriev',
+	MRGRIPH   => 'Dmitriy V. Simonov',
 	NICKOLA   => 'Nickolay Kovalev',
 	NPLATONOV => 'Nickolay Platonov',
 	NRG       => 'Odintsov Pavel',
 	NUF       => 'Dmitry Smal',
+	OLEG      => 'Oleg G',
 	OLEGSHER  => 'Oleg Sher',
 	OLEKO     => 'Oleg Kobyakovskiy',
 	PIN       => 'Dmitri Popov',
@@ -85,33 +106,45 @@ use Acme::CPANAuthors::Register (
 	RANDIR    => 'Sergey Aleynikov',
 	RHIZO     => 'Dmitry Karabanov',
 	RIIKI     => 'Oleg Prokopyev',
+	ROWAA     => 'Олег Rowaa[SR13] В. Волков',
 	RUDENKO   => 'Alexei Rudenko',
 	RUSAKOV   => 'Sergey Rusakov',
+	RUZ       => 'Руслан У. Закиров',
 	SAFRONOV  => 'Vladislav A. Safronov',
 	SASHA     => 'Alex Protasenko',
 	SERG      => 'Sergei Golubchik',
 	SERGEY    => 'Sergey Gribov',
 	SERGEYCHE => 'Sergey Chernyshev',
 	SHADOVV   => 'Victor M Elfimov',
+	SHARIFULN => 'Анатолий Шарифулин',
+	SHOORICK  => 'Александр Сапожников',
 	SHURIKO   => 'Alexander V. Alekseyenko',
 	SHV       => 'Sharypov Alexey',
 	SKORIKOV  => 'Alexey Skorikov',
 	SLEONOV   => 'Sergey Leonovich',
 	SLOBIN    => 'Sergey Lobin',
 	SNEMAROV  => 'Sergei A. Nemarov',
+	SPECTRUM  => 'Черненко Эдуард Павлович',
 	STELLAR   => 'Andrei V. Shetuhin',
 	SWAJ      => 'Alexey Semenoff',
+	SWINED    => 'Алексей Александров',
+	SYBER     => 'Олег Пронин',
+	SYP       => 'Станислав Пусеп',
+	TADAM     => 'Yury Zavarin',
+	TECHCODE  => 'Aleksandar Petrović',
 	TMULEVICH => 'Sergey Tomoulevitch',
 	TOLIKL    => 'Anatoly K. Lasareff',
 	TOYVO     => 'Anton Tayanovskyy',
 	UNERA     => 'Dmitry E. Oboukhov',
 	USTIANSKY => 'Vadim O. Ustiansky',
 	VAD       => 'Vadim Loginov',
-	VADIML    => 'Vadim Likhota ( )',
+	VADIML    => 'Vadim Likhota (Вадим Лихота)',
 	VANY      => 'Ivan B. Serezhkin',
+	VASILUS   => 'Василий Волошин',
 	VICTORI   => 'Victor Igumnov',
 	VKON      => 'Vadim Konovalov',
 	VLADB     => 'Vladimir Bogdanov',
+	VOVA      => 'Vladimir Kolpakov',
 	VOVKASM   => 'Vladimir Timofeev',
 	WOWASURIN => 'Vladimir Surin',
 	XFIRE     => 'Ilya Obshadko',
@@ -163,7 +196,7 @@ via email or RT and we will remove your name.
 
 =head1 CONTAINED AUTHORS
 
-Now B<114> Russian CPAN authors:
+Now B<147> Russian CPAN authors:
 
 	ABALAMA   => 'Lepenkov Sergey',
 	ABEL      => 'Anton Belousov',
@@ -175,21 +208,28 @@ Now B<114> Russian CPAN authors:
 	AMALTSEV  => 'Andrew Maltsev',
 	AML       => 'Alexander Lourier',
 	ANDY      => 'Andrew Shitov',
+	APLA      => 'Иван Бахчеев',
 	ARTO      => 'Artur Penttinen',
 	ASVBR     => 'Alexey Sharafutdinov',
 	ATOURBIN  => 'Alexey Tourbin',
 	AVP       => 'Alexey V. Presnyakov',
+	AZJADFTRE => 'Павел Купцов',
 	BASHLOV   => 'Dmitry Bashlov',
+	BITTER    => 'Konstantin Vlasov',
 	BOSU      => 'Boris Sukholitko',
 	BUTILW    => 'Ilya Butakov',
 	BWIZARD   => 'Arapov Denis',
 	CATONE    => 'Denis Pokataev',
+	CCCP      => 'Sivirinov Ivan',
+	CLEONTY   => 'Леонтий Чудинов',
+	DAM       => 'Дамян Иванов',
 	DARKNOS   => 'Sergey Nosenko',
 	DAVINCHI  => 'Pavel Boldin',
 	DEEMON    => 'Dmitry Dorofeev',
 	DESPAIR   => 'Walery Studennikov',
 	DMITRI    => 'Dmitri Tikhonov',
 	DMITRY    => 'Dmitry Nikolayev',
+	DMITRYNOD => 'Дмитрий Константинов',
 	DMITRYSOL => 'Dmitri Sologoubenko',
 	DMOW      => 'Dmitry Ovsyanko',
 	DPETROV   => 'Denis Petrov',
@@ -198,26 +238,37 @@ Now B<114> Russian CPAN authors:
 	FEDOROV   => 'Dmitry Fedorov',
 	FILIN     => 'Andrey  Chergik',
 	FLAMEY    => 'Irakliy Sunguryan',
+	FROLLER   => 'Александр Фролов',
 	GARIEV    => 'Igor Gariev',
 	GDSL      => 'Sergey Skvortsov',
 	GLORYBOX  => 'Sergey Sinkovskiy',
 	GOSHA     => 'Okunev Igor',
 	GRAYKOT   => 'Sergey Kotenko',
+	GRIAN     => 'Анатолий Гришаев',
 	GRISHACE  => 'Gregory Belenky',
 	ICHE      => 'Ilya Chelpanov',
 	ICHUDOV   => 'Igor Chudov',
+	IFROL     => 'Иван Фролков',
 	IGORM     => 'Igor Myroshnichenko',
 	INEULANDE => 'Ivan Neulander',
+	ISAGE     => 'Епифанов Иван',
 	ISTERIN   => 'Ilya Sterin',
+	ITRUNAEV  => 'Ivan Trunaev',
 	IVSOKOLOV => 'Ivan Sokolov',
 	KAKADU    => 'Konstantin Kapitanov',
+	KAPPA     => 'Алексей Капранов',
 	KARASIK   => 'Dmitry Karasik',
 	KDOULEPOV => 'Konstantin Doulepov',
 	KES       => 'Eugen Konkov',
 	KEU       => 'Dmitry V. Kolvakh',
+	KIRILLM   => 'Кирилл Мязин',
 	KLIMKIN   => 'Alexey Klimkin',
 	KOTEROV   => 'Dmitry Koterov',
 	KPV       => 'Pavel V. Kaygorodov',
+	KSTEPME   => 'Konstantin Stepanov',
+	KSURI     => 'Алексей Суриков',
+	KVENTIN   => 'Константин Матюхин',
+	LEO       => 'Черепанов Леонид',
 	LESV      => 'Suhanov Vadim',
 	LEXUS     => 'Usanov Alexey',
 	LIOL      => 'Lobanov Igor',
@@ -226,13 +277,16 @@ Now B<114> Russian CPAN authors:
 	LONERR    => 'Oleg A. Mamontov',
 	MAKAROW   => 'Andrew V. Makarow',
 	MAXICO    => 'Maxim Kashliak',
+	MBASOV    => 'Михаил В. Басов',
 	MIT       => 'Dmitriy Dontsov',
 	MONS      => 'Mons Anderson',
 	MPG       => 'Maxim  Grigoriev',
+	MRGRIPH   => 'Dmitriy V. Simonov',
 	NICKOLA   => 'Nickolay Kovalev',
 	NPLATONOV => 'Nickolay Platonov',
 	NRG       => 'Odintsov Pavel',
 	NUF       => 'Dmitry Smal',
+	OLEG      => 'Oleg G',
 	OLEGSHER  => 'Oleg Sher',
 	OLEKO     => 'Oleg Kobyakovskiy',
 	PIN       => 'Dmitri Popov',
@@ -243,33 +297,45 @@ Now B<114> Russian CPAN authors:
 	RANDIR    => 'Sergey Aleynikov',
 	RHIZO     => 'Dmitry Karabanov',
 	RIIKI     => 'Oleg Prokopyev',
+	ROWAA     => 'Олег Rowaa[SR13] В. Волков',
 	RUDENKO   => 'Alexei Rudenko',
 	RUSAKOV   => 'Sergey Rusakov',
+	RUZ       => 'Руслан У. Закиров',
 	SAFRONOV  => 'Vladislav A. Safronov',
 	SASHA     => 'Alex Protasenko',
 	SERG      => 'Sergei Golubchik',
 	SERGEY    => 'Sergey Gribov',
 	SERGEYCHE => 'Sergey Chernyshev',
 	SHADOVV   => 'Victor M Elfimov',
+	SHARIFULN => 'Анатолий Шарифулин',
+	SHOORICK  => 'Александр Сапожников',
 	SHURIKO   => 'Alexander V. Alekseyenko',
 	SHV       => 'Sharypov Alexey',
 	SKORIKOV  => 'Alexey Skorikov',
 	SLEONOV   => 'Sergey Leonovich',
 	SLOBIN    => 'Sergey Lobin',
 	SNEMAROV  => 'Sergei A. Nemarov',
+	SPECTRUM  => 'Черненко Эдуард Павлович',
 	STELLAR   => 'Andrei V. Shetuhin',
 	SWAJ      => 'Alexey Semenoff',
+	SWINED    => 'Алексей Александров',
+	SYBER     => 'Олег Пронин',
+	SYP       => 'Станислав Пусеп',
+	TADAM     => 'Yury Zavarin',
+	TECHCODE  => 'Aleksandar Petrović',
 	TMULEVICH => 'Sergey Tomoulevitch',
 	TOLIKL    => 'Anatoly K. Lasareff',
 	TOYVO     => 'Anton Tayanovskyy',
 	UNERA     => 'Dmitry E. Oboukhov',
 	USTIANSKY => 'Vadim O. Ustiansky',
 	VAD       => 'Vadim Loginov',
-	VADIML    => 'Vadim Likhota ( )',
+	VADIML    => 'Vadim Likhota (Вадим Лихота)',
 	VANY      => 'Ivan B. Serezhkin',
+	VASILUS   => 'Василий Волошин',
 	VICTORI   => 'Victor Igumnov',
 	VKON      => 'Vadim Konovalov',
 	VLADB     => 'Vladimir Bogdanov',
+	VOVA      => 'Vladimir Kolpakov',
 	VOVKASM   => 'Vladimir Timofeev',
 	WOWASURIN => 'Vladimir Surin',
 	XFIRE     => 'Ilya Obshadko',
@@ -280,57 +346,85 @@ Now B<114> Russian CPAN authors:
 	ZMIJ      => 'Sergei A. Fedorov',
 	ZOFFIX    => 'Zoffix Znet'
 
-And B<69> have PAUSE id, but they didn't upload any module:
+And B<101> have PAUSE id, but they didn't upload any module:
 
+	ADTIM     => 'Тимур Кондратьев',
+	ALBOVA    => 'Alexey Bovanenko',
 	ALXPLDEV  => 'Kononov Alexey',
 	AMANOKHIN => 'Alexey E.Manokhin',
 	AMONARCH  => 'Kirill Frolov',
+	ANDREY    => 'Andrey Kovbovich',
+	ANIO      => 'Ангел Колев',
 	AVOROBEY  => 'Anatoly Vorobey',
 	AZINGER   => 'Alexey Zinger',
+	BAT       => 'Тимур Бакеев',
+	BESSARABV => 'Иван Бессарабов',
 	BLINCHIK  => 'Vladislav',
 	BURNASH   => 'Anton Burnashev',
-	CCCP      => 'Sivirinov Ivan',
 	CONO      => 'Varyanick I. Alex',
 	CRUSOE    => 'Andrei V. Toutoukine',
 	CTAPUK    => 'Dmitriy Repin',
+	DENIS     => 'Денис Терещенко',
+	DEVIS     => 'Мусин Роман',
 	DIMMA     => 'Vadim Suvorov',
+	DIONYS    => 'Денис Ибаев',
+	DIVER     => 'Максим Дуюнов',
 	DMA       => 'Dmitri Alenitchev',
 	DSHAP     => 'Dmitry Shapovalov',
 	DSOKOL    => 'Denis Sokolovsky',
 	DVRYABOY  => 'Dmitriy Ryaboy',
+	DZEMA     => 'Дмитрий Дзема',
 	FATCAT    => 'Sergey Taranchenko',
+	GAMBURGER => 'Мякинин Тимур Алексеевич',
+	GERDLER   => 'Игорь Гердлер',
+	GNATYNA   => 'Александр А. Гнатына',
 	GREEN     => 'Evdokimov Denis',
+	GURETS    => 'Gurets Maxim',
 	HELLMAN   => 'Yuri A. Kabaenkov',
 	HORD      => 'Denis S Chuprunov',
 	HRG       => 'Yury Kopyl',
 	HSW       => 'Sergey Homenkow',
 	IFOMICHEV => 'Ivan Fomichev',
 	IGSTAR    => 'Sergey Rybalko',
+	IHRD      => 'Беликин Илья',
 	IOK       => 'Igor Okunev',
+	IPECHORIN => 'Иван А. Печорин',
+	JAAN      => 'Иван Валентиныч Муравьёв',
 	JUPITER   => 'Ivan Ponomarev',
 	KAZIMIROV => 'Dmitry Kazimirov',
+	KIRILL    => 'Кирилл',
 	KONSTANT  => 'Konstantin Antselovich',
+	KORSHAK   => 'Ярослав Коршак',
 	KOT       => 'Konstantin Gerasimov',
 	KOTEROFF  => 'Dmitry Koteroff',
 	KUDINOV   => 'Pavel Kudinov',
 	LINCHUS   => 'Sein Sergey',
+	LJUBEX    => 'Љубомир Самарџић',
 	MAARD     => 'Maxim Yemelyanov',
+	MADFROG   => 'Сергей Евстегнеев',
 	MAILOMAN  => 'Alex',
 	MARTYNOFF => 'Sergey Martynoff',
+	MARTYNOV  => 'Сергей Мартынов',
 	MAXX      => 'Suslov Maxim',
+	MEPHIST   => 'Maxim Nikolenko',
 	MINAKOV   => 'Vladimir Minakov',
 	MISAKA    => 'Mishka Gorodnitzky',
+	MMK       => 'Мартин Маринов',
 	MOTONAROL => 'Averyanov Ilya',
-	MRGRIPH   => 'Dmitriy V. Simonov',
 	MYAKININ  => 'Timur Myakinin',
 	NAB       => 'Nickolay Briginets',
+	NIKOLAS   => 'Николай Шуляковский',
 	OBOGREW   => 'Nikolay Kuznetsov',
 	OKOLOBOV  => 'Oleg Kolobov',
 	OLPA      => 'Oleg A. Paraschenko',
 	PROPANOID => 'Vladimir Skvortsov',
 	RAKESH    => 'Rakesh Alex',
 	RANGER    => 'Alexey Stroganov',
+	RASSIE    => 'Николай Прокошенко',
 	RAWFLUX   => 'Alexey Rybenko',
+	RSHADOW   => 'Николаев Роман',
+	RUFF      => 'Ruslan N. Marchenko',
+	SAPA      => 'Андрей Сапожников',
 	SAV       => 'Andrey Smorodin',
 	SCOUNDREL => 'Alexey Kovyrin',
 	SEZAY     => 'Sergei Zaytsev',
@@ -338,19 +432,23 @@ And B<69> have PAUSE id, but they didn't upload any module:
 	SIMPLEX   => 'Andrey Rikov',
 	SOKOL     => 'Pavel Sokol',
 	SOVA      => 'Vladimir Sovetov',
+	SPR       => 'Сергей Пригожий',
 	STEALTHY  => 'Oleg Nikitin',
 	STSAREV   => 'Sergei Tsarev',
+	SUHANOV   => 'Суханов Вячеслав',
 	TEAK      => 'Sergey Redin',
-	TECHCODE  => 'Aleksandar Petrovi',
 	TED       => 'Ruslan (Ted) Kharitonov',
+	UJIN      => 'Зарецкий Евгений Петрович',
+	VADZ      => 'Vadim Zeitlin',
+	VERRENS   => 'Денис Афонин',
+	VICTORP   => 'Victor Pryazhnikov',
 	VLADISLAV => 'Sergey',
 	VMARCHEN  => 'Vladimir Marchenko',
 	VPOROSHIN => 'Vladimir Poroshin',
 	VVD       => 'Andrey Yakovlev',
 	WEINERK   => 'Konstantin Weiner',
 	YSHTIL    => 'Yuri Shtil',
-	ZERO      => 'Oleg Alistratov',
-	ZHR       => 'Vladimir Zhirov'
+	ZHR       => 'Vladimir Zhirov',
 
 =head1 SEE ALSO
 
